==> moodle-3.8.zip: moodle/mod/forum/report/summary/lang/en/forumreport_summary.php <==
<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for the Forum report subplugin.
 *
 * @package   forumreport_summary
 * @copyright 2019 Michael Hawkins <michaelh@moodle.com>
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['attachmentcount'] = 'Number of attachments';
$string['charcount'] = 'Character count';
$string['viewcount'] = 'Number of views';
$string['earliestpost'] = 'Earliest post';
$string['eventreportdownloaded'] = 'Forum summary report downloaded';
$string['eventreportviewed'] = 'Forum summary report viewed';
$string['filter:datesbuttonlabel'] = 'Open the dates filter';
$string['filter:datesname'] = 'Dates';
$string['filter:datesfrom'] = 'From {$a}';
$string['filter:datesfromto'] = '{$a->datefrom} - {$a->dateto}';
$string['filter:datesorderwarning'] = 'Please ensure the "From" date selected is earlier than the "To" date selected.';
$string['filter:datesto'] = 'To {$a}';
$string['filter:groupsbuttonlabel'] = 'Open the groups filter';
$string['filter:groupsname'] = 'Groups';
$string['filter:groupscountall'] = 'Groups (all)';
$string['filter:groupscountnumber'] = 'Groups ({$a})';
$string['latestpost'] = 'Most recent post';
$string['exportposts'] = 'Export posts';
$string['exportpostslabel'] = 'Export posts for {$a}';
$string['nodetitle'] = 'Summary report';
$string['pluginname'] = 'Forum summary report';
$string['postcount'] = 'Number of discussions posted';
$string['privacy:metadata'] = 'The Forum summary report plugin does not store any personal data.';
$string['replycount'] = 'Number of replies posted';
$string['summary:viewall'] = 'Access summary report data for each user within a given forum or forums';
$string['summary:view'] = 'Access summary report within a given forum or forums';
$string['summarytitle'] = 'Summary report - {$a}';
$string['viewsdisclaimer'] = 'Number of views column is not filtered by group';
$string['wordcount'] = 'Word count';

==> moodle-3.8.9.zip: moodle/mod/forum/report/summary/lang/en/forumreport_summary.php <==
<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for the Forum report subplugin.
 *
 * @package   forumreport_summary
 * @copyright 2019 Michael Hawkins <michaelh@moodle.com>
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['attachmentcount'] = 'Number of attachments';
$string['charcount'] = 'Character count';
$string['viewcount'] = 'Number of views';
$string['earliestpost'] = 'Earliest post';
$string['eventreportdownloaded'] = 'Forum summary report downloaded';
$string['eventreportviewed'] = 'Forum summary report viewed';
$string['filter:datesbuttonlabel'] = 'Open the dates filter';
$string['filter:datesname'] = 'Dates';
$string['filter:datesfrom'] = 'From {$a}';
$string['filter:datesfromto'] = '{$a->datefrom} - {$a->dateto}';
$string['filter:datesorderwarning'] = 'The from date can\'t be earlier than the to date.';
$string['filter:datesto'] = 'To {$a}';
$string['filter:groupsbuttonlabel'] = 'Open the groups filter';
$string['filter:groupsname'] = 'Groups';
$string['filter:groupscountall'] = 'Groups (all)';
$string['filter:groupscountnumber'] = 'Groups ({$a})';
$string['latestpost'] = 'Most recent post';
$string['exportposts'] = 'Export posts';
$string['exportpostslabel'] = 'Export posts for {$a}';
$string['nodetitle'] = 'Summary report';
$string['pluginname'] = 'Forum summary report';
$string['postcount'] = 'Number of discussions posted';
$string['privacy:metadata'] = 'The Forum summary report plugin does not store any personal data.';
$string['replycount'] = 'Number of replies posted';
$string['summary:viewall'] = 'Access summary report data for each user within a given forum or forums';
$string['summary:view'] = 'Access summary report within a given forum or forums';
$string['summarytitle'] = 'Summary report - {$a}';
$string['viewsdisclaimer'] = 'Number of views column is not filtered by group';
$string['wordcount'] = 'Word count';
